==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/FCMPushProvider.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FCMConfiguration;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.ProviderType;
import com.okta.sdk.resource.model.PushProvider;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * FCMPushProvider
 */
@JsonPropertyOrder({ FCMPushProvider.JSON_PROPERTY_CONFIGURATION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "providerType", visible = true, defaultImpl = FCMPushProvider.class)

public class FCMPushProvider extends PushProvider implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private FCMConfiguration _configuration;

    public FCMPushProvider() {
    }

    /*
     * @JsonCreator public FCMPushProvider(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_DATE) String lastUpdatedDate ) { this(); this.id = id;
     * this.lastUpdatedDate = lastUpdatedDate; }
     */

    public FCMPushProvider _configuration(FCMConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FCMConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(FCMConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FCMPushProvider fcMPushProvider = (FCMPushProvider) o;
        return Objects.equals(this._configuration, fcMPushProvider._configuration);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(_configuration, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class FCMPushProvider {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/FCMPushProvider.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.FCMConfiguration;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.ProviderType;
import com.okta.sdk.resource.model.PushProvider;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * FCMPushProvider
 */
@JsonPropertyOrder({ FCMPushProvider.JSON_PROPERTY_CONFIGURATION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "providerType", visible = true, defaultImpl = FCMPushProvider.class)

public class FCMPushProvider extends PushProvider implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private FCMConfiguration _configuration;

    public FCMPushProvider() {
    }

    /*
     * @JsonCreator public FCMPushProvider(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_DATE) String lastUpdatedDate ) { this(); this.id = id;
     * this.lastUpdatedDate = lastUpdatedDate; }
     */

    public FCMPushProvider _configuration(FCMConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public FCMConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(FCMConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FCMPushProvider fcMPushProvider = (FCMPushProvider) o;
        return Objects.equals(this._configuration, fcMPushProvider._configuration);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(_configuration, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class FCMPushProvider {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
